//******************************************************************************
// Note: External pull-ups are needed for SDA & SCL! 
// For the MAX30102, pullups should be ~1kOhm.
// Tested with MAX30102 VIN @ 3.3V.
//
// This demo configures the MSP for I2C communication using USCI,
// and then checks if a slave with the given address is connected.
//
// This is done by checking for the presence of an ACK after sending
// an I2C START condition followed by the given slave address.
//
// To check for presence of other slave devices, change
// MAX30102_SLAVE_ADDR to something else.
//
// Much of this was taken from the TI USCI I2C Master library,
// which is located here: http://www.ti.com/lit/zip/slaa382
//
// March 2021
// Colby DeLisle, UBC
//******************************************************************************

#include "msp430g2553.h"

#define SDA_PIN BIT7            // MSP430G2553 SDA is P1.7
#define SCL_PIN BIT6            // MSP430G2553 SCL is P1.6

#define MAX30102_SLAVE_ADDR 0x57
//  Slave address for MAX30102 is 0x57, see Table 17 of datasheet.
//  Note that this doesn't include the R/W bit. So 0x57 represents
//  only the leading 7 bits of the address.


void main(void)
{
  WDTCTL = WDTPW + WDTHOLD;                   // Stop WDT

  P1DIR |= BIT0;                              // Red LED will tell us if slave connected
  P1OUT &= ~BIT0;                             // Make sure LED is off to start

  P1SEL  |= SDA_PIN + SCL_PIN;                // Assign P1.6, P1.7 to I2C duty
  P1SEL2 |= SDA_PIN + SCL_PIN;

  BCSCTL1 = CALBC1_8MHZ;                      // Calibrate clock
  DCOCTL  = CALDCO_8MHZ;

  UCB0CTL1  = UCSWRST;                        // Enable SW reset
  UCB0CTL0  = UCMST + UCMODE_3 + UCSYNC;      // I2C Master, synchronous mode
  UCB0CTL1  = UCSSEL_2 + UCSWRST;             // Use SMCLK, keep SW reset
  UCB0BR0   = 32;                             // Set prescaler (can decrease this)
  UCB0BR1   = 0;
  UCB0I2CSA = MAX30102_SLAVE_ADDR;            // Set slave address
  UCB0CTL1 &= ~UCSWRST;                       // Clear SW reset, resume operation

  // Now simply send start & stop condition and look for ACK
  
  UCB0CTL1 |= UCTR + UCTXSTT + UCTXSTP;       // I2C TX, START/STOP conditions
  
  while (UCB0CTL1 & UCTXSTP);                 // Wait for STOP condition

  if (!(UCB0STAT & UCNACKIFG)) {              // If slave ACK'd,
    P1OUT |= BIT0;                            // turn on red LED
  }
  
  LPM3;                                       // Low power mode
 
}

